setwd("/Users/rorygibb/Dropbox/PhD/chapter_predicts/predicts_analysis_201901/")

### Gibb et al, 'Land use has global and systematic effects on local zoonotic host communities"
# Script 2:  Compile all host-pathogen interactions data into a single database for matching to PREDICTS
# Data sources from EID2, GMPD2, Olival, Han, Plourde


# dependencies
library(dplyr)
library(Hmisc)
library(plyr)


### ------------- datasets -------------------

# associations data
eida = read.csv("./data/host_parasite/EID2/EID2_rorygibb/EID2_associations_20180912.csv", stringsAsFactors = F)
gmpa = read.csv("./data/host_parasite/GMPD2/GMPD2_rorygibb/GMPD2_associations_20180916.csv", stringsAsFactors = F)
olva = read.csv("./data/host_parasite/Olival/Olival_rorygibb/Olival_associations_20180915.csv", stringsAsFactors = F)
hana = read.csv("./data/host_parasite/Han/Han_rorygibb/Han_associations_20180915.csv", stringsAsFactors = F)
ploa = read.csv("./data/host_parasite/Plourde/Plourde_rorygibb/Plourde_associations_20180915.csv", stringsAsFactors = F)

# pathogen data
ei = read.csv("./data/host_parasite/EID2/EID2_rorygibb/EID2_pathogendata_allpathogens_harmonised_20180916.csv", stringsAsFactors = F)
gm = read.csv("./data/host_parasite/GMPD2/GMPD2_rorygibb/GMPD2_pathogendata_allpathogens_harmonised_20180916.csv", stringsAsFactors = F)
ol = read.csv("./data/host_parasite/Olival/Olival_rorygibb/Olival_pathogendata_allpathogens_harmonised_20180916.csv", stringsAsFactors = F)
ha = read.csv("./data/host_parasite/Han/Han_rorygibb/Han_pathogendata_allpathogens_20180915.csv", stringsAsFactors = F)
pl = read.csv("./data/host_parasite/Plourde/Plourde_rorygibb/Plourde_pathogendata_allpathogens_20180916.csv", stringsAsFactors = F)

# correct pathogen names in associations to match harmonised
eida$Pathogen_Harmonised = ei$PathogenName_Harmonised[ match(eida$Pathogen, ei$Pathogen) ]
gmpa$Pathogen_Harmonised = gm$PathogenName_Harmonised[ match(gmpa$Pathogen, gm$Pathogen) ]
olva$Pathogen_Harmonised = ol$PathogenName_Harmonised[ match(olva$Pathogen, ol$Pathogen) ]
hana$Pathogen_Harmonised = ha$PathogenName_Harmonised[ match(hana$Pathogen, ha$Pathogen) ]
ploa$Pathogen_Harmonised = pl$PathogenName_Harmonised[ match(ploa$Pathogen, pl$Pathogen) ]




### --------- Create compiled pathogens dataset  ----------

### harmonise column names across pathogen datasets

# human infective any: EID2 + external list
ei = ei[ , c("PathogenName_Harmonised", "PathogenType", "HumanInfective_Any", "HumanInfective_External",
             "DiseaseAgent", "IsZoonotic", "Disease_GIDEON", "Route_GIDEON", "AnimalReservoir_GIDEON", "VectorBorne")]
ei$AnimalReservoir_GIDEON[ ei$AnimalReservoir_GIDEON %in% c("2", "unknown")] = 1
ei$AnimalReservoir_GIDEON = as.numeric(as.vector(ei$AnimalReservoir_GIDEON))
ei$Source = "EID2"

# human infective any: external list + EID2
gm = gm[ , c("PathogenName_Harmonised", "PathogenType", "HumanInfective_Any", "HumanInfective_External",
             "DiseaseAgent", "IsZoonotic", "Disease_GIDEON", "Route_GIDEON", "AnimalReservoir_GIDEON", "VectorBorne") ]
gm$AnimalReservoir_GIDEON[ is.na(gm$AnimalReservoir_GIDEON) ] = 0
gm$Source = "GMPD2"

# human infective any: Olival (non strict) + external list
ol$HumanInfective_Any = ifelse(ol$HumanInfective_Olival == 1 | ol$HumanInfective_External == 1, 1, 0)
ol = ol[ , c("PathogenName_Harmonised", "PathogenType", "HumanInfective_Any", "HumanInfective_External",
             "DiseaseAgent", "IsZoonotic", "Disease_GIDEON", "Route_GIDEON", "AnimalReservoir_GIDEON", "VectorBorne") ]
ol$Source = "Olival"

# human infective any: internally + external list
names(ha)[4] = "HumanInfective_Any"
ha = ha[ , c("PathogenName_Harmonised", "PathogenType", "HumanInfective_Any", "HumanInfective_External",
             "DiseaseAgent", "IsZoonotic", "Disease_GIDEON", "Route_GIDEON", "AnimalReservoir_GIDEON", "VectorBorne") ]
ha$Source = "Han"

# human infective any: internally + external list
names(pl)[4] = "HumanInfective_Any"
pl = pl[ , c("PathogenName_Harmonised", "PathogenType", "HumanInfective_Any", "HumanInfective_External",
             "DiseaseAgent", "IsZoonotic", "Disease_GIDEON", "Route_GIDEON", "AnimalReservoir_GIDEON", "VectorBorne") ]
pl$Source = "Plourde"



### Combine datasets and summarise

# combine all pathogens into single dataframe
path = bind_rows(ei, gm, ol, ha, pl)

# summarise by pathogen
path1 = ddply(path, .(PathogenName_Harmonised), plyr::summarise,
              PathogenType = head(PathogenType, 1), 
              HumanInfective_Any = ifelse(sum(HumanInfective_Any, na.rm=T)>0, 1, 0),
              HumanInfective_External = ifelse(sum(HumanInfective_External, na.rm=T)>0, 1, 0),
              DiseaseAgent = ifelse(sum(DiseaseAgent, na.rm=T)>0, 1, 0),
              IsZoonotic = ifelse(sum(IsZoonotic, na.rm=T)>0, 1, 0),
              Disease_GIDEON = paste(unique(Disease_GIDEON), collapse=", "),
              Route_GIDEON = paste(unique(Route_GIDEON), collapse=", "),
              AnimalReservoir_GIDEON = ifelse(sum(AnimalReservoir_GIDEON, na.rm=T)>0, 1, 0),
              VectorBorne = ifelse(sum(VectorBorne, na.rm=T)>0, 1, 0),
              Source = paste(unique(Source), collapse=", "))

# correct formatting error
path1$Route_GIDEON[ grep("environment ,respiratory", path1$Route_GIDEON) ] = "direct, environment, respiratory"



### summarise transmission routes for pathogens with transmission data

# subset to only pathogens with route data
path2 = path1[ path1$Route_GIDEON != "NA", c("PathogenName_Harmonised", "Route_GIDEON")]

# function to add cols
transRoutes = function(x){
  
  # get specific pathogen
  p = path2[ x, ]
  r = unlist(strsplit(p$Route_GIDEON, ", "))
  
  # direct contact: droplets, direct physical contact, blood, sexual, vertical, consumption of meat/fish, airborne
  r[ r %in% c("direct", "bite", "food", "food (bushmeat)", "blood", "sexual", "airborne", "respiratory",
              "contact", "fish", "fluid", "fluids", "vertical", "direct (bite)") ] = "direct"
  
  # environmentally transmitted: water, fecal oral, soil, infection through wound
  r[ r %in% c("aeromonas bestiarum", "water", "environment", "environmental",
              "fecal-oral", "soil", "copepod", "direct fecal-oral", "trauma") ] = "environment"
  
  # vectorborne
  r[ r %in% c("vector", "tick", "anopheles triseriatus", "culex", "vector (aedes", "tick", "psorophora)")] = "vector"
  
  # miscellaneous/endogenous
  r[ r %in% c("endogenous", "endogeous", "various", "variable", "unknown") ] = "misc/endogenous/unknown"
  
  # summarise and return
  df = data.frame(PathogenName_Harmonised = p$PathogenName_Harmonised,
                  Trans_Direct = ifelse("direct" %in% r, 1, 0),
                  Trans_Environment = ifelse("environment" %in% r, 1, 0),
                  Trans_Vector = ifelse("vector" %in% r, 1, 0))
  df
}
routes = do.call(rbind.data.frame, lapply(1:nrow(path2), transRoutes))

# combine with full pathogens data and set NAs to 0s
path1 = full_join(path1, routes)
path1$Trans_Direct[ is.na(path1$Trans_Direct) ] = 0
path1$Trans_Environment[ is.na(path1$Trans_Environment) ] = 0
path1$Trans_Vector[ is.na(path1$Trans_Vector) ] = 0

# combine vector-borne columns to ensure all included
path1$Trans_Vector = ifelse(path1$VectorBorne == 1 | path1$Trans_Vector == 1, 1, 0)

# summarised pathogens
path1 = path1[ order(path1$HumanInfective_Any, path1$PathogenName_Harmonised), ]
path1 = path1[ !is.na(path1$PathogenName_Harmonised), ]
write.csv(path1, "./output/host_parasite_processed/pathogendata_allpathogens_alldatasets_harmonised_20180916.csv", row.names=F)


### Details:

# HumanInfective_Any: recorded as associated with humans either internally or in external list of human pathogens
# HumanInfective_External: recorded as associated with humans only in external list of recognised human pathogens
# Disease Agent: recorded as aetiologic agent of specific human disease in either GIDEON or Wertheim disease databases
# IsZoonotic: recorded as zoonotic (humans infected from animal reservoir) in either GIDEON, Wertheim or Taylor 2001 database
# Disease_GIDEON: disease caused by pathogen, as recorded in GIDEON database
# Route_GIDEON: transmission routes, as recorded in GIDEON database
# AnimalReservoir_GIDEON: pathogen has an animal reservoir, as recorded in GIDEON
# VectorBorne: pathogen recognised as vector borne, in either GIDEON or Wertheim
# Trans_Direct: pathogen is directly transmitted (direct contact, blood, sexual, vertical, consumption of meat/fish)
# Trans_Environment: pathogen is environmentally transmitted (water, respiratory, fecal oral, soil, wound)
# Trans_Vector: pathogen is vectorborne (from GIDEON only; redundant to VectorBorne)
# Source: sources of pathogen-host data

# 5991 pathogens and parasites in total
# 1111 human infective (internally and externally)
# 955 human infective with reference to external databases (86% of total)
# 759 are considered zoonotic (68%)
# 691 are listed as aetiologic agents of specific human disease in GIDEON/Wertheim (62%)
# of which 193 (27%) are vector borne, 296 (42%) environmentally transmitted, 416 (67%) directly transmitted




# ----------- Create compiled dataset of host pathogen associations ----------

# compile associations
eida1 = eida[ , c("Host", "Pathogen_Harmonised", "Source") ]
eida1$DetectionMethod = "Cargocarrier"
gmpa1 = gmpa[ , c("Host", "Pathogen_Harmonised", "SamplingType")]
gmpa1$Source = "GMPD2"
names(gmpa1)[3] = "DetectionMethod"
olva1 = olva[ , c("Host", "Pathogen_Harmonised", "DetectionMethod")]
olva1$Source = "Olival"
hana1 = hana[ , c("Host", "Pathogen_Harmonised", "Source")]
hana1$DetectionMethod = "PCR/Direct"
ploa1 = ploa[ , c("Host", "Pathogen_Harmonised")]
ploa1$DetectionMethod = "Reservoir"
ploa1$Source = "Plourde"

# get host synonyms
ei_host = read.csv("./data/host_parasite/EID2/EID2_rorygibb/EID2_hostdata_20180912.csv", stringsAsFactors = F)
ei_host = ei_host[ , c("Host", "Class", "Order", "Family", "Synonyms") ]
names(ei_host)[2:4] = c("HostClass", "HostOrder", "HostFamily")
ei_host = ei_host[ !duplicated(ei_host$Host), ]

gm_host = read.csv("./data/host_parasite/GMPD2/GMPD2_rorygibb/GMPD2_hostdata_20180915.csv", stringsAsFactors = F)
gm_host = gm_host[ , c("Host", "HostOrder", "HostFamily", "Synonyms")]
gm_host$HostClass = "Mammalia"
gm_host = gm_host[ !duplicated(gm_host$Host), ]

ol_host = read.csv("./data/host_parasite/Olival/Olival_rorygibb/Olival_hostdata_20180915.csv", stringsAsFactors = F)
ol_host = ol_host[ , c("Host", "HostClass", "HostOrder", "HostFamily", "Synonyms")]
ol_host = ol_host[ !duplicated(ol_host$Host), ]

ha_host = read.csv("./data/host_parasite/Han/Han_rorygibb/Han_hostdata_20180915.csv", stringsAsFactors = F)
ha_host = ha_host[ , c("Host", "HostClass", "HostOrder", "Synonyms")]
ha_host$HostFamily = ""
ha_host = ha_host[ !duplicated(ha_host$Host), ]

plo_host = read.csv("./data/host_parasite/Plourde/Plourde_rorygibb/Plourde_hostdata_20180916.csv", stringsAsFactors = F)
plo_host = plo_host[ , c("Host", "Class", "Order", "Family", "Synonyms")]
names(plo_host)[2:4] = c("HostClass", "HostOrder", "HostFamily")
plo_host = plo_host[ !duplicated(plo_host$Host), ]

# combine
eida2 = merge(eida1, ei_host, by="Host", all.x=T, all.y=F)
gmpa2 = merge(gmpa1, gm_host, all.x=T, all.y=F)
olva2 = merge(olva1, ol_host, all.x=T, all.y=F)
hana2 = merge(hana1, ha_host, all.x=T, all.y=F)
ploa2 = merge(ploa1, plo_host, all.x=T, all.y=F)

# combine and save: total 22,149 host-parasite assocations compiled from across 5 datasets
# containing 3941 unique host species and 5991 pathogens
assoc = bind_rows(eida2, gmpa2, olva2, hana2, ploa2)

# harmonise detection methods
dm = assoc$DetectionMethod
harmDM = function(x){
  d = dm[x]
  d = unlist(strsplit(d, ", "))
  dm_return = c()
  if(any(c("Cargocarrier", "NA", "Other") %in% d)) dm_return = c(dm_return, "Cargocarrier")
  if(any(c("Serology", "Antibodies", "bcELISA", "IFA", "CF", "antigen", "Antigen", "Antigens", "micropsy", "PHA", "hemmaglutination", "histopath, e-microscopy", "histopath; e microscopy",
           "PAGE", "Direct Fluorescent Antibody Testing", "agar gel immunodiffusion", "Antibodies and Isolation", "SouthernBlot") %in% d)) dm_return = c(dm_return, "Serology")
  if(any(c("SNT", "VNT", "plaque reduction neutralization", "PRNT", "neutralization test", "NT", "ELISA and plaque reduction",
           "Hemagglutination inhibition assay; Neutralization test", "virus neutralization") %in% d)) dm_return = c(dm_return, "VirusNeutralisationAssay")
  if(any(c("PCR", "PCR/Direct") %in% d)) dm_return = c(dm_return, "PCR")
  if(any(c("DNA RFLP", "EM, DNA (i.e. more than just PCR)", "Pyroseq", "RNA") %in% d)) dm_return = c(dm_return, "DirectDetection_Other")
  if(any(c("DirectBlood", "DirectFecal", "DirectOther", "Tissue", "Fecal", "Isolation", "isolation", "Cell culture", "Antibodies and Isolation") %in% d)) dm_return = c(dm_return, "DirectIsolation")
  if("Reservoir" %in% d) dm_return = c(dm_return, "Reservoir")
  if(length(dm_return)>1) dm_return = paste(dm_return, collapse=", ")
  if(is.null(dm_return)) dm_return = "Cargocarrier"
  return(dm_return)
}
dmx = unlist(lapply(1:length(dm), harmDM))
assoc$DetectionMethod = dmx

# add 'detection stringency' column (0 for cargo-carrier; 1 for serology; 2 for direct/PCR)
assoc$DetectionStringency = 0
assoc$DetectionStringency[ grep("Serology", assoc$DetectionMethod) ] = 1
assoc$DetectionStringency[ grep("VirusNeutralisationAssay", assoc$DetectionMethod) ] = 1
assoc$DetectionStringency[ grep("PCR", assoc$DetectionMethod) ] = 2
assoc$DetectionStringency[ grep("DirectIsolation", assoc$DetectionMethod) ] = 2
assoc$DetectionStringency[ grep("Reservoir", assoc$DetectionMethod) ] = 2
assoc$DetectionStringency[ grep("DirectDetection_Other", assoc$DetectionMethod) ] = 2

# save
write.csv(assoc, "./output/host_parasite_processed/associations_alldatasets_harmonised_20180916.csv", row.names=F)



# ------------- Update synonyms ---------------

# synonyms from Catalogue of Life/ITIS
all_syns = read.csv("./output/host_parasite_processed/hostdata_allsynonyms_itis_20180917.csv", stringsAsFactors=F, encoding="latin1")

# summarise by original
all_syns1 = ddply(all_syns, .(Original), plyr::summarise,
                  AcceptedBinomial=head(Accepted_name, 1),
                  Synonyms=paste(unique(Synonyms), collapse=", "))
all_syns1$AcceptedBinomial = tolower(all_syns1$AcceptedBinomial)
all_syns1$Synonyms = tolower(all_syns1$Synonyms)
all_syns1$Synonyms[ all_syns1$Synonyms == "na" ] = ""

# add columns in assoc
assoc$AcceptedBinomial = all_syns1$AcceptedBinomial[ match(assoc$Host, all_syns1$Original) ]
assoc$Synonyms = all_syns1$Synonyms[ match(assoc$Host, all_syns1$Original) ]

# reorder columns
assoc = assoc[ , c("Host", "Pathogen_Harmonised", "Source", "DetectionMethod", "DetectionStringency", "HostClass", "HostOrder", "HostFamily", "AcceptedBinomial", "Synonyms")]
names(assoc)[9:10] = c("HostAcceptedBinomial", "HostSynonyms")

# replace NAs
assoc$HostAcceptedBinomial[ is.na(assoc$HostAcceptedBinomial) ] = assoc$Host[ is.na(assoc$HostAcceptedBinomial) ]
assoc$HostSynonyms[ is.na(assoc$HostSynonyms) ] = ""

# capitalise class/order/family
assoc$HostClass = capitalize(assoc$HostClass)
assoc$HostOrder = capitalize(assoc$HostOrder)
assoc$HostFamily = capitalize(assoc$HostFamily)

# save
write.csv(assoc, "./output/host_parasite_processed/associations_alldatasets_harmonised_20180916.csv", row.names=F)




# -------------- Create compiled hosts dataset for matching to PREDICTS --------------

# exclude any pathogens only classified to genus level (sp.)
assoc$Pathogen_Harmonised[ assoc$Pathogen_Harmonised == "streptococcus dysgalactiae subsp. equisimilis" & !is.na(assoc$Pathogen_Harmonised) ]  = "streptococcus dysgalactiae subsp equisimilis"
assoc = assoc[ -grep("sp[.]", assoc$Pathogen_Harmonised), ]

# list of unique hosts (at level of accepted binomial)
hosts_vec = unique(assoc$HostAcceptedBinomial)

# read domestic hosts list
load("./data/domestics_list/domestic_species.R")
domestic = c(domestic, "apis mellifera", "canis familiaris", "bos frontalis")

# get information about pathogens of domestic species
assoc_dom = assoc[ assoc$Host %in% domestic, ]
path1$DomesticInfective = ifelse(path1$PathogenName_Harmonised %in% assoc_dom$Pathogen_Harmonised, 1, 0)

# for each host access host info and pathogen info
summariseHost = function(x){
  
  # host species x
  host = hosts_vec[x]
  print(paste("Processing:", host, sep=" "))
  
  # get pathogen associations data
  hostdat = assoc[ assoc$HostAcceptedBinomial == host, ]
  pathdat = path1[ path1$PathogenName_Harmonised %in% hostdat$Pathogen_Harmonised, ]
  
  # add column for non human AND non domestic pathogens
  pathdat$NonHumanDomInfective = ifelse(pathdat$HumanInfective_Any == 0 & pathdat$DomesticInfective == 0, 1, 0)

  # create dataframe of per-host data
  df = hostdat[ 1, c("HostAcceptedBinomial", "HostClass", "HostOrder", "HostFamily") ]
  df$HostSynonyms = paste(unique(unlist(strsplit(hostdat$HostSynonyms, ", "))), collapse=", ")
  df$IsDomestic = ifelse(df$HostAcceptedBinomial %in% domestic, 1, 0)
  
  # cargo-carrier pathogen data: binary classifications for host/nonhost
  pathdat = pathdat[ !duplicated(pathdat$PathogenName_Harmonised), ]
  df$HumanInfective_Any = ifelse(sum(pathdat$HumanInfective_Any)>0, 1, 0)
  #df$HumanInfective_External = ifelse(sum(pathdat$HumanInfective_External)>0, 1, 0)
  df$DiseaseAgent_Strict = ifelse(sum(pathdat$DiseaseAgent)>0, 1, 0)
  df$IsZoonotic_Strict = ifelse(sum(pathdat$IsZoonotic)>0, 1, 0)
  # df$Trans_Vector = ifelse(sum(pathdat$Trans_Vector)>0, 1, 0)
  # df$Trans_Environment = ifelse(sum(pathdat$Trans_Environment)>0, 1, 0)
  # df$Trans_Direct = ifelse(sum(pathdat$Trans_Direct)>0, 1, 0)
  # df$Host_Bacteria_Zoonotic = ifelse(df$IsZoonotic_Strict == 1 & "bacteria/rickettsia" %in% pathdat$PathogenType, 1, 0)
  # df$Host_Virus_Zoonotic = ifelse(df$IsZoonotic_Strict == 1 & "virus" %in% pathdat$PathogenType, 1, 0)
  # df$Host_Helminth_Zoonotic = ifelse(df$IsZoonotic_Strict == 1 & "helminth" %in% pathdat$PathogenType, 1, 0)
  
  # pathogen richness: human-associated and non-human associated (cargo carrier)
  df$PathRich_HumanInfective = sum(pathdat$HumanInfective_Any)
  df$PathRich_NonHuman = sum(pathdat$HumanInfective_Any == 0)
  df$PathRich_NonHumanDom = sum(pathdat$NonHumanDomInfective)
  
  # pathogen summaries: human
  df$PathogenDiv = paste(unique(pathdat$PathogenType[ pathdat$HumanInfective_Any == 1 ]), collapse=", ")
  df$Pathogens_Human = paste(pathdat$PathogenName_Harmonised[ pathdat$HumanInfective_Any == 1], collapse=", ")
  df$Pathogens_Zoonotic_Strict = paste(pathdat$PathogenName_Harmonised[ pathdat$IsZoonotic == 1], collapse=", ")
  df$Pathogens_NonHuman = paste(pathdat$PathogenName_Harmonised[ pathdat$HumanInfective_Any == 0], collapse=", ")
  
  # add info on detection methods/stringency (max stringency) for human pathogens
  if(df$HumanInfective_Any > 0){
    dm = unique(unlist(strsplit(hostdat$DetectionMethod[ hostdat$Pathogen_Harmonised %in% pathdat$PathogenName_Harmonised[ pathdat$HumanInfective_Any == 1] ], ", ")))
    df$DetectionMethod = paste(unique(dm), collapse=", ")
    df$DetectionStringency = max(hostdat$DetectionStringency[ hostdat$Pathogen_Harmonised %in% pathdat$PathogenName_Harmonised[ pathdat$HumanInfective_Any == 1] ])
  } else{
    df$DetectionMethod = NA
    df$DetectionStringency = NA
  }

  # add info on serological for mammals
  pathdat2 = pathdat[ pathdat$PathogenName_Harmonised %in% hostdat$Pathogen_Harmonised[ hostdat$DetectionStringency > 0 ], ]
  if(df$HostClass == "Mammalia" & nrow(pathdat2) > 0){
    df$Sero_HumanInfective_Any = ifelse(sum(pathdat2$HumanInfective_Any)>0, 1, 0)
    df$Sero_DiseaseAgent_Strict = ifelse(sum(pathdat2$DiseaseAgent)>0, 1, 0)
    df$Sero_IsZoonotic_Strict = ifelse(sum(pathdat2$IsZoonotic)>0, 1, 0)
    df$Sero_PathRich_HumanInfective = sum(pathdat2$HumanInfective_Any)
    df$Sero_PathRich_NonHuman = sum(pathdat2$HumanInfective_Any == 0)
    df$Sero_PathRich_NonHumanDom = sum(pathdat2$NonHumanDomInfective)
  } else{
    df$Sero_HumanInfective_Any  = 0
    df$Sero_DiseaseAgent_Strict = 0
    df$Sero_IsZoonotic_Strict = 0
    df$Sero_PathRich_HumanInfective = 0
    df$Sero_PathRich_NonHuman = 0
    df$Sero_PathRich_NonHumanDom = 0
  }

  # add info isolation for mammals
  pathdat2 = pathdat[ pathdat$PathogenName_Harmonised %in% hostdat$Pathogen_Harmonised[ hostdat$DetectionStringency > 1 ], ]
  if(df$HostClass == "Mammalia" & nrow(pathdat2) > 0){
    df$Isolation_HumanInfective_Any = ifelse(sum(pathdat2$HumanInfective_Any)>0, 1, 0)
    df$Isolation_DiseaseAgent_Strict = ifelse(sum(pathdat2$DiseaseAgent)>0, 1, 0)
    df$Isolation_IsZoonotic_Strict = ifelse(sum(pathdat2$IsZoonotic)>0, 1, 0)
    df$Isolation_PathRich_HumanInfective = sum(pathdat2$HumanInfective_Any)
    df$Isolation_PathRich_NonHuman = sum(pathdat2$HumanInfective_Any == 0)
    df$Isolation_PathRich_NonHumanDom = sum(pathdat2$NonHumanDomInfective)
  } else{
    df$Isolation_HumanInfective_Any = 0
    df$Isolation_DiseaseAgent_Strict = 0
    df$Isolation_IsZoonotic_Strict = 0
    df$Isolation_PathRich_HumanInfective = 0
    df$Isolation_PathRich_NonHuman = 0
    df$Isolation_PathRich_NonHumanDom = 0
  }
    
  # add data for mammal reservoirs dataset (subset to pathogens known to be serologically associated with that species)
  # pathdat_mammalsero = pathdat[ pathdat$PathogenName_Harmonised %in% unique(hostdat$Pathogen_Harmonised[ hostdat$Source %in% c("Olival", "GMPD2", "Plourde", "Han") ]), ]
  # pathdat_mammalsero = pathdat_mammalsero[ !duplicated(pathdat_mammalsero$PathogenName_Harmonised), ]
  # df$Mammalsero_HumanInfective_Any = ifelse(sum(pathdat_mammalsero$HumanInfective_Any)>0 & df$HostClass == "Mammalia", 1, 0)
  # df$Mammalsero_DiseaseAgent_Strict = ifelse(sum(pathdat_mammalsero$DiseaseAgent)>0 & df$HostClass == "Mammalia", 1, 0)
  # df$Mammalsero_IsZoonotic_Strict = ifelse(sum(pathdat_mammalsero$IsZoonotic)>0 & df$HostClass == "Mammalia", 1, 0)
  # df$Mammalsero_Trans_Vector = ifelse(sum(pathdat_mammalsero$Trans_Vector)>0 & df$HostClass == "Mammalia", 1, 0)
  # df$Mammalsero_Trans_Environment = ifelse(sum(pathdat_mammalsero$Trans_Environment)>0 & df$HostClass == "Mammalia", 1, 0)
  # df$Mammalsero_Trans_Direct = ifelse(sum(pathdat_mammalsero$Trans_Direct)>0 & df$HostClass == "Mammalia", 1, 0)
  # df$Mammalsero_Host_Bacteria_Zoonotic = ifelse(df$Mammalsero_IsZoonotic_Strict == 1 & "bacteria/rickettsia" %in% pathdat_mammalsero$PathogenType, 1, 0)
  # df$Mammalsero_Host_Virus_Zoonotic = ifelse(df$Mammalsero_IsZoonotic_Strict == 1 & "virus" %in% pathdat_mammalsero$PathogenType, 1, 0)
  # df$Mammalsero_Host_Helminth_Zoonotic = ifelse(df$Mammalsero_IsZoonotic_Strict == 1 & "helminth" %in% pathdat_mammalsero$PathogenType, 1, 0)
  # df$Mammalsero_Hyperreservoir = ifelse(df$Mammalsero_IsZoonotic_Strict == 1 & sum(pathdat_mammalsero$IsZoonotic)>2, 1, 0)
  # if(df$HostClass == "Mammalia" & !is.na(df$HostClass)){ df$Pathogens_Zoonotic_Mammalsero = paste(pathdat_mammalsero$PathogenName_Harmonised[ pathdat_mammalsero$IsZoonotic == 1], collapse=", ")
  # } else{ df$Pathogens_Zoonotic_Mammalsero = "" }

  # add source data
  df$Sources = paste(unique(hostdat$Source), collapse=", ")
  names(df)[1] = "HostBinomial"
  df
}

# run for all hosts 
hostdata = do.call(rbind.data.frame, lapply(1:length(hosts_vec), summariseHost))
hostdata$HostClass = capitalize(hostdata$HostClass)
hostdata$HostOrder = capitalize(hostdata$HostOrder)
hostdata$HostFamily = capitalize(hostdata$HostFamily)
hostdata$HostOrder[ hostdata$HostOrder == "Artiodactyla" & !is.na(hostdata$HostOrder) ] = "Cetartiodactyla"
hostdata = hostdata[ order(hostdata$HostClass, hostdata$HostOrder, hostdata$HostBinomial), ]

# remove hosts with no taxonomic matching
hostdata = hostdata[ !is.na(hostdata$HostClass), ]

# save host dataset, ready for matching to predicts: n=3883 hosts with all associated information
write.csv(hostdata, "./output/host_parasite_processed/hostdata_alldatasets_harmonised_20180916.csv", row.names=F)
