

### Gibb et al, 'Land use has global and systematic effects on local zoonotic host communities"
# Script 4: Approximate confidence in per-species 'host' status as a function of publication effort and taxonomy
# This approximation is then used to control/test for sensitivity of results to research effort in later models
# We assume all hosts are true hosts (i.e. no false positives)
# For non-hosts we use a simple model to approximate the false negative rate
# This model is 'fitted' to all described mammal and bird species (as major hosts in our database) 
# For other taxonomic groups, fitted only to species in PREDICTS, i.e. assuming randomly sampled with respect to host status

# working directory
setwd("Y:/chapter2_predicts/predicts_analysis_201901/")
setwd("/Volumes/ritd-ag-project-rd00nx-rjgib11/chapter2_predicts/predicts_analysis_201901/")

library(dplyr)
library(ggplot2)
library(Hmisc)

# functions
source("./00_function_pubmed.R")
source("./00_functions_general.R")

# cols for plotting
hostcol = "#8c510a"



# ---------------------------------- Prepare dataset --------------------------------------------

#### a. scrape PubMed publication counts for all mammal and bird species, 18/12/2019
# data compiled using rredlist and taxize

## read in mammal and bird species lists
# mm = read.csv("./data/mammal_birds_specieslists/Mammals.csv", stringsAsFactors = F)
# mm$Class = "Mammalia"
# av = read.csv("./data/mammal_birds_specieslists/Birds.csv", stringsAsFactors = F)
# av$Class = "Aves"
# 
# # combine
# spp = rbind(mm[ , c("Accepted", "Original", "IsSynonym", "Class", "Order", "Family") ],
#             av[ , c("Accepted", "Original", "IsSynonym", "Class", "Order", "Family") ])
# 
# # scrape pubmed for NumPubs
# pubmed_results = sapply(spp$Accepted, FUN=searchPubMed)
# pm_scrape = data.frame(Accepted = names(pubmed_results), NumPubs = as.vector(pubmed_results))
# 
# # save pubmed scrape
# write.csv(pm_scrape, "./output/pubmed/pubmed_mammalsbirdsall_20191218.csv", row.names=F)
# pm_scrape = read.csv("./output/pubmed/pubmed_mammalsbirdsall_20191218.csv", stringsAsFactors=F)
# 
# # combine with species basic data and save
# spp$NumPubs = pm_scrape$NumPubs
# names(spp)[1] = "bgb"
# spp$Order = capitalize(tolower(spp$Order))
# spp$Family = capitalize(tolower(spp$Family))
# write.csv(spp, "./output/researcheffort_approx/pubmed_mammalsbirds_allspecies_20191218.csv", row.names=F)
# spp = read.csv("./output/researcheffort_approx/pubmed_mammalsbirds_allspecies_20191218.csv", stringsAsFactors=FALSE)
# 


# ### b. combine all mammals and birds with fully resolved host-pathogen database

# # hosts database
# hosts = read.csv("./output/host_parasite_processed/hostdata_alldatasets_harmonised_20180916.csv", stringsAsFactors = FALSE)
# hosts = hosts[ , c(1:7, 9:12, 17:19,  21, 22, 23, 24, 28:30)]
# 
# # subset taxa
# hosts = hosts[ hosts$HostClass %in% c("Mammalia", "Aves"), ]
# 
# # function to split synonyms
# hosts$id = 1:nrow(hosts)
# splitSyns = function(x){
#   orig = hosts$HostBinomial[ hosts$id == x ]
#   syns = unlist(strsplit(hosts$HostSynonyms[ hosts$id == x ], ", "))
#   if(all(is.na(syns))) syns = c()
#   df = data.frame(id = x, Host = c(orig, syns), name_type = c("orig", rep("syn", length(syns))))
#   df
# }
# syns = do.call(rbind.data.frame, lapply(hosts$id, splitSyns))
# 
# # subset to only species in spp database and remove duplicated resolved names
# spp = spp[ !duplicated(spp$bgb), ]
# spp$bgb = tolower(spp$bgb)
# syns = syns[ syns$Host %in% spp$bgb, ]
# 
# # link ID from syns to PREDICTS
# spp$id = syns$id[ match(spp$bgb, as.vector(syns$Host)) ]
# #foo = spp[ !is.na(spp$id) & duplicated(spp$id), ] # duplicate matches?
# 
# # combine with hosts data
# res = left_join(spp, hosts, by="id")
# 
# # read in domestic species lists and mark all domestic species
# load("./data/domestics_list/domestic_species.R")
# domestic = c(domestic, "canis familiaris", "apis mellifera", "bos frontalis")
# res$IsDomestic = ifelse(res$bgb %in% domestic, 1, 0)
# 
# # remove confounding names and domestics
# res = res[ !res$bgb %in% c("axis axis", "indicator indicator", "", "homo sampiens"), ]
# res = res[ res$IsDomestic == 0, ]
# 
# # edit host status info
# res$HumanInfective_Any[ is.na(res$HumanInfective_Any) ] = 0
# res$IsZoonotic_Strict[ is.na(res$IsZoonotic_Strict) ] = 0
# res$PathRich_HumanInfective[ is.na(res$PathRich_HumanInfective) ] = 0
# res$PathRich_NonHumanDom[ is.na(res$PathRich_NonHumanDom) ] = 0
# res$Sero_HumanInfective_Any[ is.na(res$Sero_HumanInfective_Any) ] = 0
# res$Sero_IsZoonotic_Strict[ is.na(res$Sero_IsZoonotic_Strict) ] = 0
# res$Sero_PathRich_HumanInfective[ is.na(res$Sero_PathRich_HumanInfective) ] = 0
# res$Sero_PathRich_NonHumanDom[ is.na(res$Sero_PathRich_NonHumanDom) ] = 0
# 
# # correct mammal taxonomy
# res$Order[ res$Order == "Artiodactyla" & !is.na(res$Order) ] = "Cetartiodactyla"
# 
# # save data
# #write.csv(res, "./output/researcheffort_approx/Publications_HostStatus_allmammalsbirds_20191218.csv", row.names=FALSE)
# res = read.csv("./output/researcheffort_approx/Publications_HostStatus_allmammalsbirds_20191218.csv", stringsAsFactors = FALSE)


# #### c. Prepare as input data for calculating approximated false negative rates for species in PREDICTS
#
# # remove all species that are known synonyms for others (i.e. have been superceded)
# res = res[ res$IsSynonym != TRUE, ]
#
# # subset to species and columns of interest
# spp = res[ !is.na(res$NumPubs), ]
# spp = spp[ !is.na(spp$bgb) & !is.na(spp$Order) & !is.na(spp$Class), ]
#
# # set mammal host status criterion to serological
# spp$HumanInfective_Any[ spp$Class == "Mammalia" ] = spp$Sero_HumanInfective_Any[ spp$Class  == "Mammalia" ]
# spp = spp[ , c("bgb", "Class", "Order", "Family", "NumPubs", "HumanInfective_Any")]
# write.csv(spp, "./output/researcheffort_approx/MammalsBirds_numpubs_HostStatus_formodels_20191218.csv", row.names=FALSE)
#
#
#
# #### d. Combine with taxonomic, host status and publication data for all other (non-mammal and bird) species in PREDICTS
# # these have much lower host status rates so less likely to be imputed in any case
# # we assume these are a representative sample of their taxonomic groups
#
# # PREDICTS data
# load(file="./output/predicts_processed/predicts_pathogens.R")
#
# # unique species in PREDICTS
# ddx = dd1[ !duplicated(dd1$bgb), c("bgb", "Class", "Order", "Family", "NumPubs", "HumanInfective_Any")]
#
# # species within relevant studies and taxonomic families
# ddy = ddx[ ddx$bgb %in% as.character(unique(dd1$bgb[ dd1$SS_HIAMB == 1 ])), ]
# ddy = ddy[ !ddy$Class %in% c("Mammalia", "Aves"), ]
# ddy = ddy[ !ddy$Order %in% c(""), ]
#
# # combine with spp
# source_data = rbind(spp, ddy)
#
# # correction for loxodonta cyclotis (not included)
# source_data = rbind(
#   source_data,
#   data.frame(bgb="loxodonta cyclotis", Class="Mammalia", Order="Proboscidea", Family="Elephantidae", NumPubs=31, HumanInfective_Any=0)
# )
#
#write.csv(source_data, "./output/researcheffort_approx/AllTaxa_SourceData_forresearcheffortapprox.csv", row.names=FALSE)
  



# ---------- Approximate false negative probability given research effort -------------

# simple model: based on probability of being a host (pi) and probability of being detected after m pubs given you are a host (rho)
# use this to approximate false negative probability for each non-host species
# here we assume that all hosts are true positives (i.e. no false positives)

# model:
# within each relevant taxonomic subset, pi == Pr(Host) == proportion of species within taxonomic group that have known host status
# rho == Pr(Host status detected after m publications), given that you are a host == approximated using cumulative curve of publications for non hosts
# m == number of publications 

# We can use these for each species with m publications to derive an approximation for false negative rate
# i.e. the probability of being a host but not being detected,, FNR = (1 - rho) * pi
# Used to transition non-hosts into host status randomly (i.e. species w/ higher false negative prob transition more often) in bootstrap tests

# N.B.
# 1. Calculating at the Order level as sufficient taxonomic resolution to calculate curves properly and consistent with our analyses structure
# 2. For taxonomic subsets with no known hosts, impossible to derive rho and pi_approx and unclear whether because of false -ves (0/n species)
# For these, we use the average rho curve for the Class (if mammals/birds) and fixed value for pi (0.01 i.e. 1% chance of transition)

#### Function 'approximate_FNR' at species-level within order-level taxonomic stratification
#' @param m number of publications for the species
#' @param Order taxonomic order

# requires source data (used for approximating pi and rho)
source_data = read.csv("./data/researcheffort_approx/AllTaxa_SourceData_forresearcheffortapprox.csv", stringsAsFactors=F)

# function
approximate_FNR = function(num_pubs, order){
  
  # subset source data to specified order of interest
  df = source_data[ source_data$Order == order, ]
  
  # calculates approximation for rho using cumulative curve approach across all host species
  # prob detected after m publications *given you are a host*, i.e. what proportion of known hosts have been detected after m publications?
  rho_given_m = function(m){
    pp = df[ df$NumPubs <= m, ] # threshold for all species with publications <= m
    rho = sum(pp$HumanInfective_Any) / sum(df$HumanInfective_Any) # cumulative hosts
    if(is.na(rho)){ rho = 0.01 } # where there are no hosts in taxonomic group to prevent NaN
    rho
  }

  # calculates approximation for pi 'probability of being a host'
  # (proportion of all species that are known hosts)
  pi_approx = function(df){ sum(df$HumanInfective_Any) / nrow(df) }
  
  # calculate false negative rate (prob false negative given research effort m)
  calc_FNR = function(m, pi){ (1 - rho_given_m(m)) * pi }
  
  # test: run for pub counts to approximate curve
  # curve = data.frame(
  #   pubs = 0:max(df$NumPubs),
  #   FNR = unlist(lapply(0:max(df$NumPubs), calc_FNR, pi=pi_approx(df))),
  #   pi_approx = pi_approx(df)
  # )
  # ggplot(curve[ 1:2000, ], aes(log(pubs+1), FNR)) +
  #   geom_line() + xlab("log m") + ylab("False negative rate") + ggtitle("False negative rate") +
  #   xlim(-1, 6)
  # ggplot(curve[ 1:2000, ], aes(pubs, FNR)) +
  #   geom_line() + xlab("m") + ylab("False negative rate") + ggtitle("False negative rate")

  # for mammalian/avian Orders that have currently no hosts known
  # calculate average rho-given-m for all species within relevant Class (if mammals/birds)
  if(sum(df$HumanInfective_Any) == 0 & df$Class[1] %in% c("Mammalia", "Aves")){
    df = source_data[ source_data$Class == df$Class[1], ]
    pi_x = 0.01 # marginal probability of host status
  } else{
    pi_x = pi_approx(df)
  }
  
  # calculate for species of interest
  # save rho, pi (can sensitivity test), FNR
  resx = data.frame(
    rho = rho_given_m(num_pubs),
    pi = pi_x,
    FNR = calc_FNR(num_pubs, pi = pi_x)
    )
  return(resx)
}

# test
#approximate_FNR(1, "Primates")

# run approximation for all unique species in relevant PREDICTS subset
load(file="./output/predicts_processed/predicts_pathogens.R")
dd1$Order[ dd1$Order %in% c("Soricomorpha", "Erinaceomorpha") ] = "Eulipotyphla" # n.b. update mammal taxonomy
ddx = dd1[ !duplicated(dd1$bgb), c("bgb", "Class", "Order", "Family", "NumPubs", "HumanInfective_Any")]
ddx = ddx[ ddx$bgb %in% as.character(unique(dd1$bgb[ dd1$SS_HIAMB == 1 ])), ]

# wrapper function
apply_FNR = function(x){
  approximate_FNR(num_pubs = ddx$NumPubs[x], order = ddx$Order[x])
}
result = do.call(rbind.data.frame, lapply(1:nrow(ddx), apply_FNR))
ddx = cbind(ddx, result)

# visualise for non-hosts
# foo = ddx[ ddx$HumanInfective_Any == 0, ]
# ggplot(foo, aes(Class, FNR, fill=Class)) + geom_boxplot() + ylab("FNR")
# ggplot(foo[ foo$Class == "Aves", ], aes(Order, FNR, fill=Order)) + geom_boxplot()

# finally, combine with PREDICTS and save
dd1 = left_join(dd1, ddx[ , -which(names(ddx) %in% c("NumPubs", "HumanInfective_Any"))])
dd1$pi_approx = "all"
save(dd1, file="./output/predicts_processed/predicts_pathogens_researcheffort.R")




# -------------- Visualise model for Extended Data --------------

# specify legend/axis text etc
legend_text_size = 9
axis_title_size = 13.5
axis_text_size = 10

# 1. Show accrual of confidence with research effort for 5 main mammalian groups
numpubs = 1:3000
r1 = do.call(rbind.data.frame, lapply(1:3000, FUN = approximate_FNR, order="Primates")); r1$Order = "Primates"
r2 = do.call(rbind.data.frame, lapply(1:3000, FUN = approximate_FNR, order="Rodentia")); r2$Order = "Rodentia"
r3 = do.call(rbind.data.frame, lapply(1:3000, FUN = approximate_FNR, order="Carnivora")); r3$Order = "Carnivora"
r4 = do.call(rbind.data.frame, lapply(1:3000, FUN = approximate_FNR, order="Chiroptera")); r4$Order = "Chiroptera"
r5 = do.call(rbind.data.frame, lapply(1:3000, FUN = approximate_FNR, order="Cetartiodactyla")); r5$Order = "Cetartiodactyla"
r6 = do.call(rbind.data.frame, lapply(1:3000, FUN = approximate_FNR, order="Passeriformes")); r6$Order = "Passeriformes"
r7 = do.call(rbind.data.frame, lapply(1:3000, FUN = approximate_FNR, order="Psittaciformes")); r7$Order = "Psittaciformes"
r8 = do.call(rbind.data.frame, lapply(1:3000, FUN = approximate_FNR, order="Anseriformes")); r8$Order = "Anseriformes"
rr = do.call(rbind.data.frame, list(r1, r2, r3, r4, r5, r6, r7, r8))
rr$m = rep(1:3000, 8)

# plot
rho_plot = ggplot(rr, aes(log(m), rho, color=Order)) +
  geom_line(size=0.8) +
  theme_classic() +
  xlab("log PubMed publications") + ylab("Proportion known hosts detected") +
  theme(legend.position = c(0.75, 0.35), 
        legend.background = element_rect(fill=NA, color=NA),
        legend.title = element_blank(),
        axis.title = element_text(size=axis_title_size),
        legend.text = element_text(size = legend_text_size),
        axis.text = element_text(size = axis_text_size))

# plot FNR
FNR_plot = ggplot(rr, aes(log(m), FNR, color=Order)) +
  geom_line(size=0.8) +
  theme_classic() +
  xlab("log PubMed publications") + 
  ylab("Pr(False negative)") +
  theme(legend.position = "none", 
        legend.background = element_blank(),
        legend.title = element_blank(),
        axis.title = element_text(size=axis_title_size),
        legend.text = element_text(size = legend_text_size),
        axis.text = element_text(size = axis_text_size))

# plot FNR for main orders of mammals and birds in PREDICTS
load(file="./output/predicts_processed/predicts_pathogens_researcheffort.R")
ddx = dd1[ !duplicated(dd1$bgb) & dd1$HumanInfective_Any == 0,]
ddx = ddx[ ddx$SS_HIAMB == 1, ]

# plot for main groups
ddy = ddx[ ddx$Class %in% c("Amphibia", "Arachnida", "Insecta", "Mammalia", "Reptilia", "Aves"), ]
tots = ddply(ddy, .(Class), plyr::summarise, n=length(Class)) # totals to display above boxplots
tots$Class2 = paste(tots$Class, "\n(", tots$n, ")", sep="")
ddy = left_join(ddy, tots)
class_plot = ggplot(ddy, aes(Class2, FNR)) + geom_boxplot(fill="grey90") +
  theme_classic() + 
  ylab("Transition rate") +
  theme(axis.title.x = element_blank(),
        axis.title = element_text(size=axis_title_size),
        legend.text = element_text(size = legend_text_size),
        axis.text.y = element_text(size = axis_text_size),
        axis.text.x = element_text(size = axis_text_size, color="black"))

# order plots for birds and mammals
ddz = ddx[ ddx$Class %in% c("Mammalia", "Aves"), ]
tots = ddply(ddz, .(Order), plyr::summarise, n=length(Order)) # totals to display above boxplots
tots$Order2 = paste(tots$Order, " (", tots$n, ")", sep="")
ddz = left_join(ddz, tots)
ddz = ddz[ ddz$n > 1, ]
ddz = ddz[ ddz$Order %in% c("Carnivora", "Cetartiodactyla", "Chiroptera", "Didelphimorphia", "Diprotodontia", "Primates", "Rodentia",
                            "Lagomorpha", "Eulipotyphla", "Scandentia", "Acciptiriformes", "Anseriformes", "Charadriiformes",
                            "Columbiformes", "Galliformes", "Gruiformes", "Passeriformes", "Pelecaniformes", 
                            "Psittaciformes", "Apodiformes", "Strigiformes", "Piciformes", "Falconiformes"), ]
ddz = ddz[ order(ddz$Class, ddz$Order), ]
ddz$Order2 = factor(ddz$Order2, levels=unique(ddz$Order2), ordered=TRUE)
ddz$Class = factor(ddz$Class, levels=c("Mammalia", "Aves"), ordered=TRUE)
order_box = ggplot(ddz, aes(Order2, FNR, fill=Class)) + 
  geom_boxplot() +
  theme_bw() + 
  ylab("Transition rate") +
  theme(axis.title.x = element_blank(),
        #axis.text.x = element_text(angle=90, size = axis_title_size, color="black"),
        axis.text.x = element_text(angle=90, size = axis_text_size, color="black"),
        #legend.position = c(0.1, 0.15),
        legend.position="none",
        legend.title = element_blank(),
        legend.background = element_rect(fill="white", color="grey20"),
        axis.title = element_text(size=axis_title_size),
        legend.text = element_text(size = legend_text_size),
        axis.text.y = element_text(size = axis_text_size),
        panel.background = element_rect(color="black", size=0.9)) +
  scale_fill_viridis_d(begin=0.4, end=0.8)

# boxplot of pubmed pubs across all hosts/non-hosts
dda = dd1[ !duplicated(dd1$bgb), ]
dda = dda[ dda$SS_HIAMB == 1, ]
dda$IsHost = ifelse(dda$HumanInfective_Any==1, "Host", "Non-host")
tots = ddply(dda, .(IsHost), plyr::summarise, n=length(IsHost)) # totals to display above boxplots
tots$IsHost2 = paste(tots$IsHost, "\n(", tots$n, ")", sep="")
dda = left_join(dda, tots[ ,c("IsHost", "IsHost2")])
pubs_plot = ggplot(dda, aes(IsHost2, log(NumPubs+1))) + 
  geom_boxplot(fill="grey70",  col="black") +
  theme_classic() + 
  ylab("log Pubmed publications") + 
  theme(axis.title.x = element_blank(),
        axis.title = element_text(size=axis_title_size),
        legend.text = element_text(size = legend_text_size),
        axis.text.y = element_text(size = axis_text_size),
        axis.text.x = element_text(size = axis_text_size, color="black"))

# Histogram of number of imputed species across 1000 bootstrapped models
# same process used to randomly transition species in bootstrap
spp = ddx[ !duplicated(ddx$bgb), c("bgb", "Order", "FNR", "HumanInfective_Any") ]
spp$ImputeRate = spp$FNR
spp$ImputeRate[ is.na(spp$ImputeRate) ] = 0.001
ran_impute = function(n){ rbinom(1, 1, prob=spp$ImputeRate[n]) }
result = c()
for(i in 1:1000){
  spp$IsHost_imp = unlist(lapply(1:nrow(spp), ran_impute))
  number_species_imputed = sum(spp$IsHost_imp[ spp$HumanInfective_Any == 0 ]) # calculate number imputed for saving
  result = c(result, number_species_imputed)
}
res2 = data.frame(x = "dat", n_imp = result)
impute_histogram = ggplot(res2, aes(n_imp)) + 
  geom_histogram(binwidth=5, color="black", size=0.3, fill=hostcol, alpha=0.6) +
  #geom_density(color="black", size=0.3, fill=hostcol, alpha=0.6) + 
  theme_classic() +
  ylab("Number of bootstrap models") +
  xlim(80, 160) +
  xlab("Num. species transitioned") +
  theme(panel.grid.minor = element_blank(),
        panel.grid.major = element_blank(),
        axis.text = element_text(size=axis_text_size),
        axis.title = element_text(size=axis_title_size))

# plot all and save
pp = gridExtra::arrangeGrob(rho_plot, FNR_plot, pubs_plot, class_plot, 
                            order_box, impute_histogram, heights=c(1, 1), widths=c(0.9, 0.9, 0.9, 0.9, 1, 1.1, 1.1),
                            layout_matrix = rbind(c(1, 1, 2, 2, 3, 4, 4),
                                                  c(5, 5, 5, 5, 5, 6, 6)))
pp = ggpubr::as_ggplot(pp)  +
  cowplot::draw_plot_label(label = c("A", "B", "C", "D", "E", "F"), 
                           fontface = "bold", size = 20, 
                           x = c(0, 0.275, 0.545, 0.69, 0.04, 0.675), y = c(1, 1, 1, 1, 0.4925, 0.4925))
ggsave(pp, filename="./output/figures/nature_ms3_jan2019/ExtendedData_ResearchEffortApprox.png",
       device="png", width=16, height=9, units="in", dpi=600, scale=0.9)




