
# Gibb et al, 'Land use has global and systematic effects on zoonotic host communities'
# Code 25: Create extra summary tables for SI

setwd("/Users/rorygibb/Dropbox/PhD/chapter_predicts/predicts_analysis_201901/")
setwd("/Volumes/ritd-ag-project-rd00nx-rjgib11/chapter2_predicts/predicts_analysis_201901/")

# dependencies
library(plyr)
library(dplyr)
library(ddply)
library(gridExtra)
library(ggplot2)
library(RColorBrewer)

source("./00_functions_general.R")

# PREDICTS/pathogens data
load(file="./data/predicts_processed/predicts_pathogens_researcheffort.R")
dd1 = dd1[ dd1$SS_HIAMB == 1, ]

# prepare land use categories
dd1 = prepareLandUse(dd1)

# summarised
dd1_site = read.csv("./output/predicts_sites_formodelling/Tier1_HIAMB_predicts_sites_SR0_20190514.csv", stringsAsFactors = F)


# ---------- summarise land use -------------

# summarise all hosts dataset by land use for paper
dd2 = dd1[ dd1$SSS %in% dd1_site$SSS, ]
lusummary = ddply(dd2, .(Predominant_land_use, Use_intensity), plyr::summarize,
                  LandUseTypeAggregated = head(LandUseType, 1),
                  UseIntensityAggregate = head(UseIntensity, 1),
                  NumStudies = length(unique(SS)),
                  NumSites = length(unique(SSS)),
                  NumSpecies = length(unique(bgb)),
                  Regions = paste(unique(UN_region), collapse=", "),
                  TaxRange = paste(unique(Class), collapse=", "))
lusummary$Use_intensity = factor(lusummary$Use_intensity, levels=c("Minimal", "Light", "Intense", "Cannot decide"), ordered=T)
lusummary = lusummary[ order(lusummary$Predominant_land_use, lusummary$Use_intensity), ]
write.csv(lusummary, "./output/summary_tables/SI_LandUseType_Summary.csv", row.names=F)



# ---------- human population densities across land uses ----------

dd1_site = read.csv("./output/predicts_sites_formodelling/Tier1_HIAMB_predicts_sites_SR0_20190514.csv", stringsAsFactors = F)
models_df = dd1_site[ dd1_site$UseIntensity != "Cannot decide", ]

datx = models_df
datx$LU_UI = as.character(datx$LU_UI)
datx$LU_UI[ datx$LU_UI == "1_Primary_Minimal"] = "Primary\n(minimal)"
datx$LU_UI[ datx$LU_UI == "Primary_Substantial"] = "Primary\n(substantial)"
datx$LU_UI[ datx$LU_UI == "Secondary_Minimal"] = "Secondary\n(minimal)"
datx$LU_UI[ datx$LU_UI == "Secondary_Substantial"] = "Secondary\n(substantial)"
datx$LU_UI[ datx$LU_UI == "Managed_Minimal"] = "Managed\n(minimal)"
datx$LU_UI[ datx$LU_UI == "Managed_Substantial"] = "Managed\n(substantial)"
datx$LU_UI[ datx$LU_UI == "Urban_Minimal"] = "Urban\n(minimal)"
datx$LU_UI[ datx$LU_UI == "Urban_Substantial"] = "Urban\n(substantial)"
datx$LU_UI = factor(datx$LU_UI, levels=c("Primary\n(minimal)", "Primary\n(substantial)",
                                         "Secondary\n(minimal)", "Secondary\n(substantial)",
                                         "Managed\n(minimal)",  "Managed\n(substantial)",
                                         "Urban\n(minimal)",  "Urban\n(substantial)"), ordered=T)

c1 = viridis(200)[40]
c2 = viridis(200)[70]
c3 = viridis(200)[110]
c4 = viridis(200)[150]

# totals to display above boxplots
tots = ddply(datx, .(LU_UI), plyr::summarise, n=length(LU_UI))

px = ggplot() + 
  geom_boxplot(data=datx, aes(LU_UI, LogHumanDensity, fill=factor(LandUseType))) + 
  theme_bw() +
  ylab("log Human population density 2005 (persons per sq. km)") +
  xlab("Land use type\n(intensity)") +
  scale_fill_manual(values=c("1_Primary" = c4,
                             "Secondary" = c2, 
                             "Managed" = c3, 
                             "Urban" = c1)) +
  theme(axis.title=element_text(size=13),
        axis.text=element_text(size=12),
        legend.text=element_text(size=12),
        legend.title=element_text(size=12),
        legend.position="none") +
  geom_text(data = tots, aes(x = LU_UI, y=10.1, label=n), size=4.5)

ggsave(px, file="./output/figures/MS_HumanPopulation_landuse.png",
       device="png", width=9, height=6, units="in", dpi=600) 



# ------------------ create summary host-pathogen table for the extended data/suppmat -----------------

# dependencies
library(Hmisc)
library(dplyr)
library(plyr)

## List of human-shared hosts with PREDICTS matches
h = read.csv("./output/summary_tables/HostSpecies_humaninfective_withPREDICTSmatches.csv", stringsAsFactors = F)
h$HostBinomial = capitalize(h$HostBinomial)

# for mammals, host status based on serological criteria
h$HumanInfective_Any[ h$HostClass == "Mammalia" ] = h$Sero_HumanInfective_Any[ h$HostClass == "Mammalia" ]
h$IsZoonotic_Strict[ h$HostClass == "Mammalia" ] = h$Sero_IsZoonotic_Strict[ h$HostClass == "Mammalia" ]

# sort pathogen names
sortPathNames = function(n){
  p = unlist(strsplit(h$Pathogens_Human[n], ", "))
  paste(capitalize(p), collapse=", ")
}
h$Pathogens_Human = sapply(1:nrow(h), sortPathNames)

# get predicts studies and sites
load("./output/predicts_processed/predicts_pathogens.R")
dd1 = dd1[ dd1$id %in% h$id, ]
ddd = ddply(dd1, .(id), plyr::summarise, id2 = head(id, 1),
            NumStudies = length(unique(SS)),
            NumSites = length(unique(SSS)))
#ddx = dd1[ !duplicated(dd1$bgb), c("id", "NumPubs", "ProbDetection") ]
h = full_join(h, ddd)
#h = left_join(h, ddx)

# subset to only hosts
h = h[ h$HumanInfective_Any == 1, ]
h$HostBinomial = capitalize(h$HostBinomial)
h$HostCriterion = ifelse(h$HostClass == "Mammalia", "Serological", "Cargo- carrier")
h$HostCriterion[ h$Isolation_IsZoonotic_Strict == 1 ] = "Detection/ reservoir"

# sort out phylogenetic information
h[ h$HostBinomial == "Querula purpurata", c("HostClass", "HostOrder", "HostFamily")] = c("Aves", "Passeriformes", "Cotingidae")
h = h[ order(h$HostClass, h$HostOrder, h$HostFamily, h$HostBinomial), ]

# h1
h1 = h[ , c("HostBinomial", "HostClass", "HostOrder", "HostFamily", "Pathogens_Human", "PathogenDiv", "HostCriterion",
            "IsZoonotic_Strict","PathRich_HumanInfective", "PathRich_NonHumanDom", "Sources", "NumStudies", "NumSites") ]
names(h1) = c("Host binomial", "Class", "Order", "Family", "Human-shared pathogens", "Human-shared pathogen diversity", "Evidence of host status",
              "Zoonotic agent host (strict)", "Pathogen richness (human-shared)", "Pathogen richness (not human-shared)", 
              "Data sources", "Num studies (PREDICTS)", "Num sites (PREDICTS)")
write.csv(h1, "./output/summary_tables/HostSpecies_humaninfective_withPREDICTSmatches_forSuppMat_24052019.csv", row.names=F)

# Non-host species information
load("./output/predicts_processed/predicts_pathogens.R")
ddx = dd1[ dd1$id %in% h$id, ]
dd1 = dd1[ !dd1$bgb %in% ddx$bgb, ]
ddd = ddply(dd1, .(bgb), plyr::summarise,
            # SpeciesBinomial = head(bgb, 1),
            # Class = head(Class, 1), 
            # Order = head(Order, 1),
            # Family = head(Family, 1),
            NumStudies = length(unique(SS)),
            NumSites = length(unique(SSS)))
dx = dd1[ !duplicated(dd1$bgb), c("bgb", "Class", "Order", "Family")]
ddd1 = full_join(ddd, dx)
names(ddd1)[1] = "SpeciesBinomial"
ddd1 = ddd1[ order(ddd1$Class, ddd1$Order, ddd1$Family, ddd1$SpeciesBinomial), ]
ddd2 = ddd1[ ddd1$Class != "", ]
ddd2$SpeciesBinomial = capitalize(ddd2$SpeciesBinomial)
names(ddd2)[2:3] = c("Num studies (PREDICTS)", "Num sites (PREDICTS)")
write.csv(ddd2, "./output/summary_tables/NonHostSpecies_PREDICTS.csv", row.names=F)


